@@ -206,7 +206,20 @@ deploy_launcher_data_cb (AnjutaLauncher *launcher,
   AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
   GError *error = NULL;
 
-  if (sp->deploy_msg_view)
+  if (g_strrstr(chars, "rsync: not found") && sp->deploy_msg_view)
+  {
+    ianjuta_message_view_append (sp->deploy_msg_view,
+				 IANJUTA_MESSAGE_VIEW_TYPE_ERROR,
+				 "Rsync missing on target",
+				 "Try using an sdk image or installing rsync",
+				 &error);
+    if (error)
+    {
+      g_warning ("Error appending to message view: %s", error->message);
+      g_clear_error (&error);
+    }
+  }
+  else if (sp->deploy_msg_view)
   {
     /* Append to the buffer for the message view to deal with the newlines */
     ianjuta_message_view_buffer_append (sp->deploy_msg_view, chars, &error);
@@ -572,7 +585,10 @@ remote_debug_dialog (AnjutaPluginSdk *sp)
   /* Make hitting enter in the entry do the window default action */
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 
-  gtk_entry_set_text (GTK_ENTRY (entry), sp->gdb_remote_command);
+  if (sp->gdb_remote_command)
+    gtk_entry_set_text (GTK_ENTRY (entry), sp->gdb_remote_command);
+  else
+    gtk_entry_set_text (GTK_ENTRY (entry), "/usr/local/bin/");
   gtk_size_group_add_widget (control_group, entry);
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 2);
 
@@ -642,6 +658,8 @@ remote_run_dialog (AnjutaPluginSdk *sp, gchar *prev_cmd)
 
   if (prev_cmd)
     gtk_entry_set_text (GTK_ENTRY (entry), prev_cmd);
+  else
+    gtk_entry_set_text (GTK_ENTRY (entry), "/usr/local/bin/");
 
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 2);
 
@@ -735,7 +753,7 @@ do_local_gdb (AnjutaPluginSdk *sp)
   cmd = g_strdup_printf (LOCAL_GDB_COMMAND, sp->triplet, 
       script_name, sp->gdb_local_path);
   cur_dir = g_get_current_dir ();
-  ianjuta_terminal_execute_command (terminal, cur_dir, cmd, &error);
+  ianjuta_terminal_execute_command (terminal, cur_dir, cmd, NULL, &error);
 
   if (error != NULL)
   {
@@ -932,7 +950,7 @@ get_host_component ()
 static void
 update_path (AnjutaPluginSdk *sp)
 {
-  char *path = NULL;
+  const gchar *path;
   gchar *new_path_component = NULL;
   GArray *path_array = NULL;
   char **pathv = NULL;
@@ -964,7 +982,7 @@ update_path (AnjutaPluginSdk *sp)
   }
 
   /* get current path. do not free */
-  path = getenv ("PATH");
+  path = g_getenv ("PATH");
 
   /* split old path up */
   pathv = g_strsplit (path, ":", -1);
@@ -1282,10 +1300,116 @@ setup_buildable (AnjutaPluginSdk *sp)
   g_free (command);
 }
 
-
+#ifdef ANJUTA_2_28_OR_HIGHER
 /* Callbacks fired when preferences changed */
 static void
-sdk_root_preference_notify_cb (GConfClient *client, guint cnxn_id, 
+sdk_root_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gchar *value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+
+  g_free (sp->sdk_root);
+  sp->sdk_root = anjuta_preferences_get (sp->prefs, PREFS_PROP_SDK_ROOT);
+
+  update_environment (sp);
+}
+
+static void
+triplet_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gchar *value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+
+  g_free (sp->triplet);
+  sp->triplet = anjuta_preferences_get (sp->prefs, PREFS_PROP_TRIPLET);
+
+  update_environment (sp);
+  setup_buildable (sp);
+}
+
+static void
+rootfs_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gchar *value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+  gchar *rootfs = NULL;
+
+  if (BEAVER_IS_TARGET_QEMU (sp->target))
+  {
+    rootfs = anjuta_preferences_get (sp->prefs, PREFS_PROP_ROOTFS);
+    g_object_set (sp->target, "rootfs", rootfs, NULL);
+    g_free (rootfs);
+  }
+}
+
+static void
+kernel_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gchar *value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+  gchar *kernel = NULL;
+
+  if (BEAVER_IS_TARGET_QEMU (sp->target))
+  {
+    kernel = anjuta_preferences_get (sp->prefs, PREFS_PROP_KERNEL);
+    g_object_set (sp->target, "kernel", kernel, NULL);
+    g_free (kernel);
+  }
+}
+
+static void
+poky_mode_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gboolean value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+
+  sp->poky_mode = anjuta_preferences_get_bool (sp->prefs, PREFS_PROP_POKY_MODE);
+
+  update_environment (sp);
+}
+
+static void
+poky_root_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gchar *value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+
+  g_free (sp->poky_root);
+  sp->poky_root = anjuta_preferences_get (sp->prefs, PREFS_PROP_POKY_ROOT);
+
+  update_environment (sp);
+}
+
+static void
+target_mode_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gboolean value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+
+  sp->target_mode = anjuta_preferences_get_bool (sp->prefs, PREFS_PROP_TARGET_MODE);
+
+  setup_target (sp);
+}
+
+static void
+target_ip_preference_notify_cb (AnjutaPreferences *pref, const gchar *key,
+    const gchar *value, gpointer userdata)
+{
+  AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
+  gchar *ip_address = NULL;
+
+  if (sp->target &&
+      BEAVER_IS_TARGET_DEVICE (sp->target))
+  {
+    ip_address = anjuta_preferences_get (sp->prefs, PREFS_PROP_TARGET_IP);
+    g_object_set (sp->target, "ip-address", ip_address, NULL);
+    g_free (ip_address);
+  }
+}
+#else
+/* Callbacks fired when preferences changed */
+static void
+sdk_root_preference_notify_cb (GConfClient *client, guint cnxn_id,
     GConfEntry *entry, gpointer userdata)
 {
   AnjutaPluginSdk *sp = (AnjutaPluginSdk *)userdata;
@@ -1388,6 +1512,7 @@ target_ip_preference_notify_cb (GConfClient *client, guint cnxn_id,
     g_free (ip_address);
   }
 }
+#endif
 
 /* 
  * Callbacks for when a value for "project_root_uri" is added to the shell aka
@@ -1497,6 +1622,11 @@ anjuta_plugin_sdk_activate (AnjutaPlugin *plugin)
   sp->remote_stop_action = anjuta_ui_get_action (ui, "ActionGroupSdk",
       "ActionStopRemote");
 
+#ifndef GDB_INTEGRATION
+  gtk_action_set_visible (sp->remote_debug_action, FALSE);
+  gtk_action_set_visible (sp->remote_debug_stop_action, FALSE);
+#endif
+
   gtk_action_set_sensitive (sp->qemu_start_action, FALSE);
   gtk_action_set_sensitive (sp->qemu_shutdown_action, FALSE);
   gtk_action_set_sensitive (sp->deploy_action, FALSE);
@@ -1506,6 +1636,24 @@ anjuta_plugin_sdk_activate (AnjutaPlugin *plugin)
   gtk_action_set_sensitive (sp->remote_profile_action, FALSE);
   gtk_action_set_sensitive (sp->remote_stop_action, FALSE);
 
+#ifdef ANJUTA_2_28_OR_HIGHER
+  sp->sdk_root_notifyid = anjuta_preferences_notify_add_string (sp->prefs,
+      PREFS_PROP_SDK_ROOT, sdk_root_preference_notify_cb, sp, NULL);
+  sp->triplet_notifyid = anjuta_preferences_notify_add_string (sp->prefs,
+      PREFS_PROP_TRIPLET, triplet_preference_notify_cb, sp, NULL);
+  sp->rootfs_notifyid = anjuta_preferences_notify_add_string (sp->prefs,
+      PREFS_PROP_ROOTFS, rootfs_preference_notify_cb, sp, NULL);
+  sp->kernel_notifyid = anjuta_preferences_notify_add_string (sp->prefs,
+      PREFS_PROP_KERNEL, kernel_preference_notify_cb, sp, NULL);
+  sp->poky_root_notifyid = anjuta_preferences_notify_add_string (sp->prefs,
+      PREFS_PROP_POKY_ROOT, poky_root_preference_notify_cb, sp, NULL);
+  sp->poky_mode_notifyid = anjuta_preferences_notify_add_bool (sp->prefs,
+      PREFS_PROP_POKY_MODE, poky_mode_preference_notify_cb, sp, NULL);
+  sp->target_mode_notifyid = anjuta_preferences_notify_add_bool (sp->prefs,
+      PREFS_PROP_TARGET_MODE, target_mode_preference_notify_cb, sp, NULL);
+  sp->target_ip_notifyid = anjuta_preferences_notify_add_string (sp->prefs,
+      PREFS_PROP_TARGET_IP, target_ip_preference_notify_cb, sp, NULL);
+#else
   sp->sdk_root_notifyid = anjuta_preferences_notify_add (sp->prefs,
       PREFS_PROP_SDK_ROOT, sdk_root_preference_notify_cb, sp, NULL);
   sp->triplet_notifyid = anjuta_preferences_notify_add (sp->prefs,
@@ -1522,14 +1670,20 @@ anjuta_plugin_sdk_activate (AnjutaPlugin *plugin)
       PREFS_PROP_TARGET_MODE, target_mode_preference_notify_cb, sp, NULL);
   sp->target_ip_notifyid = anjuta_preferences_notify_add (sp->prefs,
       PREFS_PROP_TARGET_IP, target_ip_preference_notify_cb, sp, NULL);
+#endif
 
   sp->sdk_root = anjuta_preferences_get (sp->prefs, PREFS_PROP_SDK_ROOT);
   sp->triplet = anjuta_preferences_get (sp->prefs, PREFS_PROP_TRIPLET);
 
   sp->poky_root = anjuta_preferences_get (sp->prefs, PREFS_PROP_POKY_ROOT);
-  sp->poky_mode = anjuta_preferences_get_int (sp->prefs, PREFS_PROP_POKY_MODE);
 
+#ifdef ANJUTA_2_28_OR_HIGHER
+  sp->poky_mode = anjuta_preferences_get_bool (sp->prefs, PREFS_PROP_POKY_MODE);
+  sp->target_mode = anjuta_preferences_get_bool (sp->prefs, PREFS_PROP_TARGET_MODE);
+#else
+  sp->poky_mode = anjuta_preferences_get_int (sp->prefs, PREFS_PROP_POKY_MODE);
   sp->target_mode = anjuta_preferences_get_int (sp->prefs, PREFS_PROP_TARGET_MODE);
+#endif
 
   setup_target (sp);
   update_environment (sp);
